==> beast-night-tv-0.0.9.tar.gz: beast-night-tv-0.0.9/README.md <==
<div align=center>

# JAK-Python-Package
![PyPI](https://img.shields.io/pypi/v/beast-night-tv?style=for-the-badge)
![PyPI - Downloads](https://img.shields.io/pypi/dd/beast-night-tv?style=for-the-badge)
[![Code Style: Black](https://img.shields.io/badge/Code%20Style-Black-000000.svg?style=for-the-badge)](https://github.com/psf/black)
![GitHub Repo Stars](https://img.shields.io/github/stars/Jonak-Adipta-Kalita/JAK-Python-Package?style=for-the-badge)
![GitHub Forks](https://img.shields.io/github/forks/Jonak-Adipta-Kalita/JAK-Python-Package?style=for-the-badge)
![GitHub Watchers](https://img.shields.io/github/watchers/Jonak-Adipta-Kalita/JAK-Python-Package?style=for-the-badge)

</div>

Go to the [Package](https://pypi.org/project/beast-night-tv/)

## Installation
### Windows
```bash
pip install beast-night-tv
```

### Linux
```bash 
python3 pip install beast-night-tv
```

### MacOS
```bash
pip install beast-night-tv
```

## Check if your changes Work
### Clone the Repository
In a Directory open a Terminal and type:
```bash
git clone https://github.com/Jonak-Adipta-Kalita/JAK-Python-Package.git
```

### Installing The Required Modules
To install the required modules, just open a terminal in the directory where this project is cloned. Now type: 
```bash
pip install virtualenv
virtualenv venv
.\venv\Scripts\activate
pip install -r .\requirements.txt
``` 
and hit enter.

### Make Change
Make some changes and save them.

### Install the changed Package in the Virtual Environement
```bash
pip install .
```

## Technology(s) Used

-   Language: [Python](https://python.org/)

## Contributors
<a href = "https://github.com/Jonak-Adipta-Kalita/JAK-Python-Package/graphs/contributors">
	<img src = "https://contrib.rocks/image?repo=Jonak-Adipta-Kalita/JAK-Python-Package"/>
</a>

==> beast-night-tv-1.0.2.tar.gz: beast-night-tv-1.0.2/README.md <==
<div align=center>

# JAK-Python-Package
![PyPI](https://img.shields.io/pypi/v/beast-night-tv?style=for-the-badge)
![PyPI - Downloads](https://img.shields.io/pypi/dd/beast-night-tv?style=for-the-badge)
[![Code Style: Black](https://img.shields.io/badge/Code%20Style-Black-000000.svg?style=for-the-badge)](https://github.com/psf/black)
[![Documentation Status](https://readthedocs.org/projects/jak-python-package/badge/?version=latest&style=for-the-badge)](https://jak-python-package.readthedocs.io/en/latest/?badge=latest)
![GitHub Repo Stars](https://img.shields.io/github/stars/Jonak-Adipta-Kalita/JAK-Python-Package?style=for-the-badge)
![GitHub Forks](https://img.shields.io/github/forks/Jonak-Adipta-Kalita/JAK-Python-Package?style=for-the-badge)
![GitHub Watchers](https://img.shields.io/github/watchers/Jonak-Adipta-Kalita/JAK-Python-Package?style=for-the-badge)
![Made by JAK](https://img.shields.io/badge/BeastNight%20TV-Made%20by%20JAK-blue?style=for-the-badge)

</div>

Go to the [Package](https://pypi.org/project/beast-night-tv/), [Documentation](https://jak-python-package.readthedocs.io/)

## Installation
### Windows
```bash
pip install beast-night-tv
```

### Linux
```bash 
python3 pip install beast-night-tv
```

### MacOS
```bash
pip install beast-night-tv
```

## Check if your changes Work
### Clone the Repository
In a Directory open a Terminal and type:
```bash
git clone https://github.com/Jonak-Adipta-Kalita/JAK-Python-Package.git
```

### Installing The Required Modules
To install the required modules, just open a terminal in the directory where this project is cloned. Now type: 
```bash
pip install virtualenv
virtualenv venv
.\venv\Scripts\activate
pip install -r .\requirements.txt
``` 
and hit enter.

### Make Change
Make some changes and save them.

### Install the changed Package in the Virtual Environement
```bash
pip install .
```

## Technology(s) Used

-   Language: [Python](https://python.org/)

## Contributors
<a href = "https://github.com/Jonak-Adipta-Kalita/JAK-Python-Package/graphs/contributors">
	<img src = "https://contrib.rocks/image?repo=Jonak-Adipta-Kalita/JAK-Python-Package"/>
</a>
